---
title: <span class="badge object-type-scalar"></span> DurationSeconds
---
# <span class="badge object-type-scalar"></span> DurationSeconds

Time: duration (s)

## Definition

```python
# Time: duration (s)
DurationSeconds: typing.Literal["dtdurations"] = "dtdurations"
```
